Package 'taxonomy.tools'

Title: Tools to Work with Taxonomic Data
Description: Tools to Work with Taxonomic Data.
Authors: Francisco Rodriguez-Sanchez [aut, cre] (ORCID: <https://orcid.org/0000-0002-7981-1599>)
Maintainer: Francisco Rodriguez-Sanchez <[email protected]>
License: GPL (>= 3)
Version: 0.0.3
Built: 2026-05-28 08:44:08 UTC
Source: https://github.com/Pakillo/taxonomy.tools

Help Index


Parallelised matching of plant taxonomic names against WCVP

Description

Parallelised version of rWCVP::wcvp_match_names() to check plant taxonomic names against the World Checklist of Vascular Plants (WCVP), using future.apply::future.apply().

Usage

wcvp_match_names_parallel(
  df = NULL,
  name_col = NULL,
  author_col = NULL,
  fuzzy = TRUE,
  plan = "multisession",
  cores = 1,
  ...
)

Arguments

df

Data frame containing taxonomic names to be matched against WCVP.

name_col

Character. The column in 'df' containing the taxon names for matching.

author_col

Character. The column in 'df' that has the name authority, to aid matching. Set to NULL to match with no author string.

fuzzy

Logical; whether or not fuzzy matching should be used for names that could not be matched exactly.

plan

Character. Name of a future::plan() to be used for parallelisation. Recommended plan is "multisession". Use "sequential" for non-parallel processing.

cores

Number of cores to use in parallel.

...

Further arguments to be passed to rWCVP::wcvp_match_names()

Value

A data frame

Examples

## Not run: 
df <- data.frame(taxon = c("Laurus nobilis", "Laurus nobilis", "Laurus nobili"),
                  author = c(NA, "L.", NA))
out <- wcvp_match_names_parallel(df, name_col = "taxon", author_col = "author",
  cores = 3)

## End(Not run)

Resolve multiple matches in WCVP

Description

This function tries to resolve automatically the cases of multiple matches found after running a vector of taxonomic names against the World Checklist of Vascular Plants (WCVP).

Usage

wcvp_resolve_multiple_matches(df = NULL, name_col = NULL)

Arguments

df

Data frame with matching results, as produced by rWCVP::wcvp_match_names() or wcvp_match_names_parallel()

name_col

Character. Name of the column in 'df' containing the taxon names.

Value

A data frame

Author(s)

Adapted from rWCVP vignette

See Also

https://matildabrown.github.io/rWCVP/articles/redlist-name-matching.html

Examples

## Not run: 
df <- data.frame(taxon = "Acacia dealbata")
matching <- wcvp_match_names_parallel(df, name_col = "taxon")
out <- wcvp_resolve_multiple_matches(matching, name_col = "taxon")

## End(Not run)